OC.L10N.register(
    "bruteforcesettings",
    {
    "Add" : "Lisa"
},
"nplurals=2; plural=(n != 1);");
